@@ -264,15 +264,15 @@ set_info (GTopProcViewData *d, gint pid)
 	
 	glibtop_get_proc_time (&proctime, t->pid);
 
-	t->hz = proctime.frequency ? proctime.frequency : 1000000;
+	t->frequency = proctime.frequency ? proctime.frequency : 1000000;
 	
-	t->utime  = ((unsigned long) (proctime.utime * 100) / t->hz);
-	t->stime  = ((unsigned long) (proctime.stime * 100) / t->hz);
-	t->cutime = ((unsigned long) (proctime.cutime * 100) / t->hz);
-	t->cstime = ((unsigned long) (proctime.cstime * 100) / t->hz);
+	t->utime  = ((unsigned long) (proctime.utime * 100) / t->frequency);
+	t->stime  = ((unsigned long) (proctime.stime * 100) / t->frequency);
+	t->cutime = ((unsigned long) (proctime.cutime * 100) / t->frequency);
+	t->cstime = ((unsigned long) (proctime.cstime * 100) / t->frequency);
 	
 	t->start_time =
-		((unsigned long) (proctime.start_time * 100) / t->hz);
+		((unsigned long) (proctime.start_time * 100) / t->frequency);
 
 	/* FIXME! */
 	data.pcpu = data.pmem = 0;
@@ -458,7 +458,10 @@ get_map_rows (pid_t pid, GTopProcMapRow **rs)
 			}
 #endif
 
-			row->filename = (gchar *) filename;
+			if (filename)
+				row->filename = (gchar *) filename;
+			else
+				row->filename = glibtop_strdup ("");
 		}
 
 		rows = g_new (GTopProcMapRow *, procmap.number+1);
@@ -623,7 +626,7 @@ add_mem_map (GTopProcViewData *d, gint pid)
 
 		dt->mcl_sw = gtk_scrolled_window_new (NULL,NULL);
 		gtk_scrolled_window_set_policy
-			(GTK_SCROLLED_WINDOW (dt->icl_sw),
+			(GTK_SCROLLED_WINDOW (dt->mcl_sw),
 			 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_container_add (GTK_CONTAINER (dt->mcl_sw), dt->mcl);
 
