@@ -469,8 +469,8 @@ fsusage_properties_init (GnomePropertyObject *object)
 	gtk_container_border_width (GTK_CONTAINER (vb), GNOME_PAD_SMALL);
 
 	frame = gtk_frame_new (_("Select information to show"));
-	table = gtk_table_new (3, 1, TRUE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	table = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
 
 	button = gtk_radio_button_new_with_label
 		(NULL, _("Show 1k-blocks reserved blocks"));
@@ -512,22 +512,22 @@ fsusage_properties_init (GnomePropertyObject *object)
 
 	gtk_signal_connect
 		(GTK_OBJECT (button), "toggled", radio_inodes_cb, cb_data);
-	gtk_table_attach_defaults (GTK_TABLE (table), button, 0, 1, 2, 3);
+	gtk_table_attach_defaults (GTK_TABLE (table), button, 1, 2, 0, 1);
 
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new ("");
-	table = gtk_table_new (GTOP_NUM_FSTYPES+2, 8, FALSE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	table = gtk_table_new (GTOP_NUM_FSTYPES+2, 3, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 1);
 
 	label = gtk_check_button_new_with_label
 		(_("Only show selected filesystems"));
 	if (temp_properties->selected_fs)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (label), TRUE);
 	gtk_signal_connect
-		(GTK_OBJECT (label), "toggled", selected_fs_cb, label);
-	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 8, 0, 1);
+		(GTK_OBJECT (label), "toggled", selected_fs_cb, cb_data);
+	gtk_table_attach_defaults (GTK_TABLE (table), label, 0, 3, 0, 1);
 
 	for (i = 0; i < GTOP_NUM_FSTYPES; i++) {
 		RadioButtonCbData *cb_data;
