@@ -11,8 +11,9 @@ extern GnomeMDI *mdi;
 extern gboolean gtop_is_running;
 
 extern GnomeUIInfo fileMenu [];
-extern GnomeUIInfo mdiMenu [];
 
+extern void gtop_mdi_init (void);
 extern void gtop_mdi_start (gboolean);
+extern void gtop_quit (void);
 
 #endif
