@@ -527,12 +527,14 @@ graph_properties_init (GnomePropertyObject *object)
 					   &gtop_properties.graph.font_name,
 					   &gtop_properties.graph.font);
 
+	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 	gtk_container_add (GTK_CONTAINER (frame), table);
 	gtk_box_pack_start (GTK_BOX (vb), frame, FALSE, TRUE, 0);
 
 	frame = gtk_frame_new (_("Graph Geometry"));
-	table = gtk_table_new (5, 4, TRUE);
-	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD << 2);
+	table = gtk_table_new (5, 4, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD);
+	gtk_container_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
 
 	label = gtk_label_new (_("Default width:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
