@@ -58,7 +58,7 @@ delete_event_handler (GtkWidget *widget)
         return TRUE;
 }
 
-void
+static void
 about_cb (GtkWidget *widget, void *data)
 {
 	GtkWidget *about;
@@ -110,46 +110,40 @@ static GnomeUIInfo toolbar [] = {
 /* menu system */
 
 GnomeUIInfo helpMenu [] = {
-#if 0
-	GNOMEUIINFO_HELP("gtop"),
-#endif
-	{GNOME_APP_UI_ITEM, N_("About..."), NULL, about_cb, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_ABOUT, 0, 0, NULL},
-	GNOMEUIINFO_END
-};
-  
-GnomeUIInfo fileMenu [] = {
-	{GNOME_APP_UI_ITEM, N_("Properties..."), NULL, gtop_show_properties,
-	 NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP, 0, 0, NULL},
+#if HAVE_LIBGTOP_DOCU
+	GNOMEUIINFO_HELP ("libgtop"),
 	GNOMEUIINFO_SEPARATOR,
-	{GNOME_APP_UI_ITEM, N_("Exit"), NULL, delete_event_handler, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXIT, 'q', 0, NULL},
+#endif
+	GNOMEUIINFO_MENU_ABOUT_ITEM (about_cb, NULL),
 	GNOMEUIINFO_END
 };
 
+GnomeUIInfo settingsMenu [] = {
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_PREFERENCES_ITEM (gtop_show_properties, NULL),
+	GNOMEUIINFO_END
+};
+  
 GnomeUIInfo emptyMenu[] = {
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo mainMenu [] = {
-	GNOMEUIINFO_SUBTREE (N_("File"), fileMenu),
-	GNOMEUIINFO_SUBTREE (N_("Pages"), emptyMenu),
-	GNOMEUIINFO_SUBTREE (N_("MDI"), mdiMenu),
-	GNOMEUIINFO_SUBTREE (N_("Help"), helpMenu),
+	GNOMEUIINFO_MENU_FILE_TREE (fileMenu),
+	GNOMEUIINFO_MENU_SETTINGS_TREE (settingsMenu),
+	GNOMEUIINFO_MENU_WINDOWS_TREE (emptyMenu),
+	GNOMEUIINFO_MENU_HELP_TREE (helpMenu),
 	GNOMEUIINFO_END
 };
 
 #define ADD_PROPERTIES(x,y) gtop_property_object_list = g_list_append (gtop_property_object_list, gnome_property_object_new (& ## x ## Property_Descriptor, &gtop_properties. ## y ##))
 
+void
+gtop_quit (void)
+{
+	delete_event_handler (NULL);
+}
 
-#ifndef GNOME_CLIENT_RESTARTED
-#define GNOME_CLIENT_RESTARTED(client) \
-  (GNOME_CLIENT_CONNECTED (client) && \
-   (strcmp (gnome_client_get_config_prefix (client), \
-	    gnome_client_get_global_config_prefix (client)) != 0))
-#endif /* GNOME_CLIENT_RESTARTED */
-
-        
 int
 main (int argc, char *argv[])
 {
@@ -177,30 +171,33 @@ main (int argc, char *argv[])
         gtk_signal_connect (GTK_OBJECT (client), "die",
                             GTK_SIGNAL_FUNC (client_die), NULL);
 
-	restarted= GNOME_CLIENT_RESTARTED (client);
-	
 	/* prepare MDI interface. */
 
 	mdi = GNOME_MDI (gnome_mdi_new ("gtop", _("GNOME System Monitor")));
+	mdi->tab_pos = GTK_POS_TOP;
 
 	gtk_signal_connect (GTK_OBJECT (mdi), "destroy",
 			    GTK_SIGNAL_FUNC (delete_event_handler), NULL);
 
+	/* initialize MDI. */
+	gtop_mdi_init ();
+
 	/* set up MDI menus and toolbar */
 	gnome_mdi_set_menubar_template (mdi, mainMenu);
 	gnome_mdi_set_toolbar_template (mdi, toolbar);
 
 	/* and document menu and document list paths */
-	gnome_mdi_set_child_menu_path (mdi, _("File"));
-	gnome_mdi_set_child_list_path (mdi, _("Pages/"));
+	gnome_mdi_set_child_menu_path (mdi, GNOME_MENU_FILE_STRING);
+	gnome_mdi_set_child_list_path (mdi, GNOME_MENU_WINDOWS_PATH);
 
 	/* Add properties (notebook pages). */
 	ADD_PROPERTIES (Global, global);
 	ADD_PROPERTIES (ProcView, procview);
 	ADD_PROPERTIES (ProcFields, procfields);
-	ADD_PROPERTIES (SummaryColors, summary);
+	ADD_PROPERTIES (Summary, summary);
+	ADD_PROPERTIES (SummaryColors, summary_colors);
 	ADD_PROPERTIES (MemUsage, memusage);
-	ADD_PROPERTIES (FsUsage, fsusage);
+       	ADD_PROPERTIES (FsUsage, fsusage);
 	ADD_PROPERTIES (Graph, graph);
 
 	/* Read properties. */
@@ -211,7 +208,8 @@ main (int argc, char *argv[])
 
 	/* Restore MDI session. */
 
-	if (restarted || gtop_properties.global.save_session) {
+	if ((gnome_client_get_flags (client) & GNOME_CLIENT_RESTORED) ||
+	    gtop_properties.global.save_session) {
 		gnome_config_push_prefix
 			(gnome_client_get_config_prefix (client));
 
