@@ -57,6 +57,9 @@ gtop_show_properties (void)
 	
 	win = gnome_property_box_new ();
 
+	gtk_notebook_set_scrollable (GTK_NOTEBOOK (GNOME_PROPERTY_BOX (win)->notebook),
+				     TRUE);		      
+
 	for (c = gtop_property_object_list; c; c = c->next) {
 		gnome_property_object_register
 			(GNOME_PROPERTY_BOX (win),
