@@ -7,13 +7,11 @@
 #define SESSION_H
 
 #include <gnome.h>
-#include <getopt.h>
 
 #include <global.h>
 
 BEGIN_GNOME_DECLS
 
-extern int restarted;
 extern GtkAllocation *initial_geometry;
 
 extern const struct poptOption gtop_options [];
